@@ -1,11 +1,11 @@
 from __future__ import division, print_function
+from io import open
 import logging
 import os
-from six.moves.urllib.request import urlopen
-from six.moves.urllib.error import URLError
 
 import codetree.fileutils as fileutils
-from io import open
+from ..six.moves.urllib.request import urlopen
+from ..six.moves.urllib.error import URLError
 
 
 class HandlerResult(object):
